==> tpcclib-0.7.9-src.tar.gz: v2/libtpcimage/test_tpcimage.h <==
#ifndef _TEST_TPCIMAGE_H_
#define _TEST_TPCIMAGE_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include "tpcimage.h"
/*****************************************************************************/

/*****************************************************************************/
/* image */
extern int test_imgInit(TPCSTATUS *status);
extern int test_imgFree(TPCSTATUS *status);
extern int test_imgAllocate(TPCSTATUS *status);
extern int test_imgHasData(TPCSTATUS *status);
extern int test_imgHasTimes(TPCSTATUS *status);
extern int test_imgHasCounts(TPCSTATUS *status);
extern int test_imgHasWeights(TPCSTATUS *status);
extern int test_imgMinMax(TPCSTATUS *status);
extern int create_img(
  IMG *img,
  const unsigned int dimz, const unsigned int dimy, const unsigned int dimx, const unsigned int dimt
);
/* imageheader */
extern int test_imgFillOHeader(TPCSTATUS *status);
/* imageio */
extern int test_imgFormatDescr(TPCSTATUS *status);
extern int test_imgDefaultExtension(TPCSTATUS *status);
extern int test_imgRead(TPCSTATUS *status);
extern int test_imgWrite(TPCSTATUS *status);
extern int test_imgFormatFromFName(TPCSTATUS *status);
extern int test_imgFormatIdentify(TPCSTATUS *status);
/* imagedcm */
extern int test_imgReadDICOM(TPCSTATUS *status);
/* imagenii */
extern int test_niftiCreateFNames(TPCSTATUS *status);
extern int test_imgReadNifti(TPCSTATUS *status);
extern int test_imgWriteNifti(TPCSTATUS *status);
extern int test_imgSetNiftiHeader(TPCSTATUS *status);
extern int test_imgGetNiftiHeader(TPCSTATUS *status);
/* imagesif */
extern int test_imgToSIF(TPCSTATUS *status);
extern int test_imgFromSIF(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCIMAGE */

==> tpcclib-0.8.1-src.tar.gz: v2/libtpcimage/test_tpcimage.h <==
#ifndef _TEST_TPCIMAGE_H_
#define _TEST_TPCIMAGE_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include "tpcimage.h"
/*****************************************************************************/

/*****************************************************************************/
/* image */
extern int test_imgInit(TPCSTATUS *status);
extern int test_imgFree(TPCSTATUS *status);
extern int test_imgAllocate(TPCSTATUS *status);
extern int test_imgHasData(TPCSTATUS *status);
extern int test_imgHasTimes(TPCSTATUS *status);
extern int test_imgHasCounts(TPCSTATUS *status);
extern int test_imgHasWeights(TPCSTATUS *status);
extern int test_imgNaNs(TPCSTATUS *status);
extern int test_imgMinMax(TPCSTATUS *status);
extern int test_imgXRange(TPCSTATUS *status);
extern int create_img(
  IMG *img,
  const unsigned int dimz, const unsigned int dimy, const unsigned int dimx, const unsigned int dimt
);
/* imageheader */
extern int test_imgFillOHeader(TPCSTATUS *status);
/* imageio */
extern int test_imgFormatDescr(TPCSTATUS *status);
extern int test_imgDefaultExtension(TPCSTATUS *status);
extern int test_imgRead(TPCSTATUS *status);
extern int test_imgWrite(TPCSTATUS *status);
extern int test_imgFormatFromFName(TPCSTATUS *status);
extern int test_imgFormatIdentify(TPCSTATUS *status);
/* imagedcm */
extern int test_imgReadDICOM(TPCSTATUS *status);
extern int test_imgWriteDICOM(TPCSTATUS *status);
/* imagenii */
extern int test_niftiCreateFNames(TPCSTATUS *status);
extern int test_imgReadNifti(TPCSTATUS *status);
extern int test_imgWriteNifti(TPCSTATUS *status);
extern int test_imgSetNiftiHeader(TPCSTATUS *status);
extern int test_imgGetNiftiHeader(TPCSTATUS *status);
/* imagesif */
extern int test_imgToSIF(TPCSTATUS *status);
extern int test_imgFromSIF(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* imagecomp */
extern int test_imgCompareMatrixSize(TPCSTATUS *status);
extern int test_imgCompareUnit(TPCSTATUS *status);
extern int test_imgCompareConc(TPCSTATUS *status);
extern int test_imgCompareTimes(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCIMAGE */
